@@ -3,9 +3,7 @@ use std::ptr;
 
 use crate::error::SparseLinearAlgebraError;
 // use crate::operators::BinaryOperatorType;
-use crate::operators::{
-    binary_operator::BinaryOperator, mask::MatrixMask, options::OperatorOptions,
-};
+use crate::operators::{binary_operator::BinaryOperator, options::OperatorOptions};
 use crate::util::{ElementIndexSelector, ElementIndexSelectorGraphblasType, IndexConversion};
 use crate::value_types::sparse_matrix::SparseMatrix;
 use crate::value_types::value_type::{AsBoolean, ValueType};
@@ -103,7 +101,7 @@ where
         rows_to_insert_into: &ElementIndexSelector, // length must equal row_height of matrix_to_insert
         columns_to_insert_into: &ElementIndexSelector, // length must equal column_width of matrix_to_insert
         scalar_to_insert: &ScalarToInsert,
-        mask_for_matrix_to_insert_into: &MatrixMask<MaskValueType, AsBool>,
+        mask_for_matrix_to_insert_into: &SparseMatrix<AsBool>,
     ) -> Result<(), SparseLinearAlgebraError>;
 }
 
@@ -227,7 +225,7 @@ macro_rules! implement_insert_scalar_into_matrix_trait {
                 rows_to_insert_into: &ElementIndexSelector, // length must equal row_height of matrix_to_insert
                 columns_to_insert_into: &ElementIndexSelector, // length must equal column_width of matrix_to_insert
                 scalar_to_insert: &$value_type_scalar_to_insert,
-                mask_for_matrix_to_insert_into: &MatrixMask<MaskValueType, AsBool>,
+                mask_for_matrix_to_insert_into: &SparseMatrix<AsBool>,
             ) -> Result<(), SparseLinearAlgebraError> {
                 let context = matrix_to_insert_into.context();
 
@@ -418,7 +416,7 @@ mod tests {
                 &rows_to_insert,
                 &columns_to_insert,
                 &scalar_to_insert,
-                &mask.into(),
+                &mask,
             )
             .unwrap();
 
